-- string codes for hour and minute changing
local alarmTable = {
  ["kp8"] = "011201hour",
  ["kp2"] = "0112-1hour",
  ["kp6"] = "005901minute",
  ["kp4"] = "0059-1minute",
}

-- string codes for AM/PM changing
local ampmTable = {
  ["AM"] = "PM",
  ["PM"] = "AM",
}

-- string codes for double-digit hour and minute numbers
local tempTable = {
  [1] = "0",
  [2] = "",
}

-- number codes for math problem
local mathTable = {
  ["kp0"] = 0,
  ["kp1"] = 1,
  ["kp2"] = 2,
  ["kp3"] = 3,
  ["kp4"] = 4,
  ["kp5"] = 5,
  ["kp6"] = 6,
  ["kp7"] = 7,
  ["kp8"] = 8,
  ["kp9"] = 9,
}

function love.keypressed(key)
  if key == "escape" then
    -- quit alarm
    love.event.quit()
  elseif key == "kp+" and not alarm.beeping then
    -- toggle AM/PM
    tempAlarm.ampm = ampmTable[tempAlarm.ampm]
  elseif key == "kpenter" then
    if alarm.beeping then
      -- enter answer
      local answerTable = {
        ["+"] = math.n1 + math.n2,
        ["-"] = math.n1 - math.n2,
      }
      if answerTable[math.symbol] == math.answer then
        love.audio.stop(beeping)
        alarm.beeping = false
      end
      math.answer = ""
    else
      -- set alarm time
      for i,e in pairs(alarm) do
        alarm[i] = tempAlarm[i]
      end
      alarm.set = true
    end
  elseif key == "kp." then
    if alarm.beeping then
      -- delete answer
      math.answer = ""
    else
      -- sleep mode
      sleepMode = not sleepMode
    end
  end
  
  -- change alarm hour/minute
  if alarmTable[key] ~= nil and not alarm.beeping then
    local temp = tonumber(tempAlarm[alarmTable[key]:sub(7)])
    temp = temp + tonumber(alarmTable[key]:sub(5,6))
    
    if temp < tonumber(alarmTable[key]:sub(1,2)) then
      temp = tonumber(alarmTable[key]:sub(3,4))
    elseif temp > tonumber(alarmTable[key]:sub(3,4)) then
      temp = tonumber(alarmTable[key]:sub(1,2))
    end
    
    tempAlarm[alarmTable[key]:sub(7)] = tostring(tempTable[#tostring(temp)]..temp)
  end
  
  -- input answer
  if mathTable[key] ~= nil and alarm.beeping then
    math.answer = tonumber(math.answer..mathTable[key])
  end
end